import React from 'react';
import styled from 'styled-components';

import defaultTheme from '../../theme';
import { paddable, flexbox, alignColumn, alignRow } from '../../utils';

export interface BoxProps {
  centered?: boolean;
  padded?: boolean;
  size?: number | number[];
  type?: 'row' | 'column';
  verticalAlign?: 'start' | 'center' | 'end';
  floated?: 'left' | 'right';
  textAlign?: 'left' | 'right' | 'center' | 'justify';
}

export const Box = styled.div<BoxProps>(
  {
    display: 'flex',
    padding: '0.5em',
  },
  (props) => ({
    flexFlow: `${props.type} wrap`,
    ...(props.type === 'column' ? alignColumn(props) : alignRow(props)),
  }),
  ({ textAlign }) => (textAlign ? { textAlign } : null),
  flexbox,
  paddable,
);

Box.defaultProps = {
  theme: defaultTheme,
  type: 'column',
};

/**
 * Helpers for migrating from Semantic UI
 */

export type GridType<T = {}> = React.FC<
  React.DetailedHTMLProps<
    React.HTMLAttributes<HTMLDivElement>,
    HTMLDivElement
  > &
    BoxProps &
    T & {
      as?: any;
    }
>;

export type GridParent = GridType & {
  Row: GridType;
  Column: GridType<{
    width?:
      | '1'
      | '2'
      | '3'
      | '4'
      | '5'
      | '6'
      | '7'
      | '8'
      | '9'
      | '10'
      | '11'
      | '12'
      | '13'
      | '14'
      | '15'
      | '16';
  }>;
};

export const Grid: GridParent = ({ ref, type, ...props }) => (
  <Box {...props} type="row" />
);

Grid.Row = ({ ref, type, ...props }) => <Box type="row" {...props} />;
Grid.Column = ({ ref, type, width, ...props }) => {
  if (width) {
    const size = parseInt(width);

    if (size) {
      props.size = size;
    }
  }

  return <Box type="column" {...props} />;
};
