import React, { useState } from 'react';
import { ThemeProvider } from 'styled-components';

import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { action } from '@storybook/addon-actions';

import {
  Button,
  createTheme,
  Box,
  Input,
  GlobalStyle,
  Header,
  Checkbox,
  Container,
  Divider,
} from '../src';

const theme = createTheme({
  colors: { primary: '#2CB2E8' },
});

console.log('THEME', theme);

const ThemeWrapper = (storyfn: any) => (
  <ThemeProvider theme={theme}>
    <Container>
      <GlobalStyle></GlobalStyle>
      {storyfn()}
    </Container>
  </ThemeProvider>
);

const CheckboxTest = () => {
  const [checked, setChecked] = useState(true);

  console.log('checked', checked);

  return (
    <div>
      <Checkbox
        checked={checked}
        onChange={(e) => setChecked(e.target.checked)}
      >
        Click me
      </Checkbox>
      <br />
      <Checkbox
        checked={checked}
        onChange={(e) => setChecked(e.target.checked)}
      ></Checkbox>
    </div>
  );
};

storiesOf('Inputs', module)
  .addDecorator(ThemeWrapper)
  .addDecorator(withInfo)
  .addParameters({
    info: { inline: true },
  })
  .add('Button', () => (
    <div>
      <Button onClick={action('clicked')}>Default</Button>
      <Button onClick={action('clicked')} disabled>
        Disabled
      </Button>
      <Button onClick={action('clicked')} secondary>
        Secondary
      </Button>
      <Button onClick={action('clicked')} secondary color="red">
        Secondary
      </Button>
      <Button onClick={action('clicked')} color="red">
        Red
      </Button>
      <Button onClick={action('clicked')} color="green">
        Green
      </Button>
      <Button onClick={action('clicked')} color="blue">
        Blue
      </Button>
      <Button onClick={action('clicked')} color="yellow">
        Yellow
      </Button>
      <Button onClick={action('clicked')} color="purple">
        Purple
      </Button>
    </div>
  ))
  .add('Input', () => (
    <>
      <div>
        <Input placeholder="Placeholder" />
        <br />
        <Input defaultValue="Value" />
      </div>

      <CheckboxTest />

      <Header>Labelled</Header>
      <Input placeholder="Username" label="Username" fluid />
      <Divider />
      <Input placeholder="Password" label="Password" fluid />

      <div>
        <Header>Login</Header>
        <Box type="row">
          <Box size={0.5}>
            <Input placeholder="Username" label="Username" />

            <Input placeholder="Password" label="Password" />

            <Box floated="right">
              <Button secondary color="red">
                Forgot Password
              </Button>
              <Divider hide />
              <Button>Login</Button>
            </Box>
          </Box>
          <Box size={0.5}>Test</Box>
        </Box>
      </div>
    </>
  ));
